#include <Xm/Xm.h>

/* build this programmatically but put it in fallbacks[] */
char Version_resource[50];

String fallbacks[] = {
    "XEphem*AAVSO*Designation.value: 0214-03",
    "XEphem*AAVSO*EndDate.value: latest",
    "XEphem*AAVSO*Name.value: OMI CET",
    "XEphem*AAVSO*Plot.CCDB.set: True",
    "XEphem*AAVSO*Plot.CCDI.set: True",
    "XEphem*AAVSO*Plot.CCDR.set: True",
    "XEphem*AAVSO*Plot.CCDV.set: True",
    "XEphem*AAVSO*Plot.Discrepant.set: False",	/* Aaron asked this default */
    "XEphem*AAVSO*Plot.FainterThan.set: True",
    "XEphem*AAVSO*Plot.Visual.set: True",
    "XEphem*AAVSO*SmoothDays.value: 15",
    "XEphem*AAVSO*StartDate.value: default",
    "XEphem*AAVSO.x: 201",
    "XEphem*AAVSO.y: 36",
    "XEphem*About.x: 100",
    "XEphem*About.y: 10",
    "XEphem*AboutMap.background: #113",
    "XEphem*AboutMap.foreground: #eef",
    "XEphem*Annotation*File.value:",
    "XEphem*Annotation.height: 250",
    "XEphem*Annotation.width: 375",
    "XEphem*Annotation.x: 50",
    "XEphem*Annotation.y: 575",
    "XEphem*BinaryStar.height: 250",
    "XEphem*BinaryStar.width: 450",
    "XEphem*BinaryStar.x: 200",
    "XEphem*BinaryStar.y: 200",
    "XEphem*CloseList*Text.value:",
    "XEphem*CloseObjs*AutoList.set: False",
    "XEphem*CloseObjs*AutoUp.set: False",
    "XEphem*CloseObjs*List.doubleClickInterval: 500",
    "XEphem*CloseObjs*List.visibleItemCount: 10",
    "XEphem*CloseObjs*Mag.value: 20.0",
    "XEphem*CloseObjs*OmitFixedPairs.set: True",
    "XEphem*CloseObjs*OmitOwnMoons.set: True",
    "XEphem*CloseObjs*Sep.value: 2.0",
    "XEphem*CloseObjs.height: 400",
    "XEphem*CloseObjs.width: 500",
    "XEphem*CloseObjs.x: 200",
    "XEphem*CloseObjs.y: 200",
    "XEphem*Colors*NightMode.set: False",
    "XEphem*Colors.x: 462",
    "XEphem*Colors.y: 0",
    "XEphem*Confirm.No.set: False",
    "XEphem*CoordsConv*Equinox.value: 2000.0",
    "XEphem*CoordsConv.x: 200",
    "XEphem*CoordsConv.y: 200",
    "XEphem*DB.height: 400",
    "XEphem*DB.width: 285",
    "XEphem*DB.x: 46",
    "XEphem*DB.y: 11",
    "XEphem*DBManage*Load1.set: True",
    "XEphem*DBManage*CheckAltNames.set: True",
    "XEphem*DataSetup*Air.set: False",
    "XEphem*DataSetup*Alt.set: True",
    "XEphem*DataSetup*Az.set: True",
    "XEphem*DataSetup*Cns.set: False",
    "XEphem*DataSetup*Dec.set: True",
    "XEphem*DataSetup*EaDst.set: False",
    "XEphem*DataSetup*EaLght.set: False",
    "XEphem*DataSetup*EcLat.set: False",
    "XEphem*DataSetup*EcLong.set: False",
    "XEphem*DataSetup*Elong.set: True",
    "XEphem*DataSetup*GHA.set: False",
    "XEphem*DataSetup*GLat.set: False",
    "XEphem*DataSetup*GLong.set: False",
    "XEphem*DataSetup*HA.set: False",
    "XEphem*DataSetup*HJD.set: False",
    "XEphem*DataSetup*HeLat.set: False",
    "XEphem*DataSetup*HeLong.set: False",
    "XEphem*DataSetup*Horizon.value: 0",
    "XEphem*DataSetup*HrsUp.set: False",
    "XEphem*DataSetup*JD.set: False",
    "XEphem*DataSetup*Limb.set: True",
    "XEphem*DataSetup*MillSA.set: False",
    "XEphem*DataSetup*PA.set: False",
    "XEphem*DataSetup*PMDec.set: False",
    "XEphem*DataSetup*PMRA.set: False",
    "XEphem*DataSetup*Phase.set: False",
    "XEphem*DataSetup*RA.set: True",
    "XEphem*DataSetup*RisAz.set: False",
    "XEphem*DataSetup*RisTm.set: True",
    "XEphem*DataSetup*Sep.set: False",
    "XEphem*DataSetup*SepPartner.labelString: Sun",
    "XEphem*DataSetup*SetAz.set: False",
    "XEphem*DataSetup*SetTm.set: True",
    "XEphem*DataSetup*Size.set: False",
    "XEphem*DataSetup*SnDst.set: False",
    "XEphem*DataSetup*SnLght.set: False",
    "XEphem*DataSetup*Spect.set: False",
    "XEphem*DataSetup*Text.value:",
    "XEphem*DataSetup*TrnAlt.set: True",
    "XEphem*DataSetup*TrnAz.set: False",
    "XEphem*DataSetup*TrnTm.set: True",
    "XEphem*DataSetup*Uran2k.set: False",
    "XEphem*DataSetup*Uranom.set: False",
    "XEphem*DataSetup*VMag.set: True",
    "XEphem*DataSetup*Zenith.set: False",
    "XEphem*DataSetup.x: 346",
    "XEphem*DataSetup.y: 304",
    "XEphem*DataTable.x: 400",
    "XEphem*DataTable.y: 25",
    "XEphem*DateFormat.D/M/Y.set: False",
    "XEphem*DateFormat.M/D/Y.set: True",
    "XEphem*DateFormat.Y/M/D.set: False",
    "XEphem*DialogShell*translations: #override \\n"
	"Ctrl<Key>f: XeGo(1) \\n"
	"Ctrl<Key>b: XeGo(-1) \\n"
	"Ctrl<Key>u: XeGo(0)",
    "XEphem*Earth*EarthMap.foreground: #fff",
    "XEphem*Earth*ZoomScale.value: 62",
    "XEphem*Earth*cylGraphic.set: False",
    "XEphem*Earth*cylImage.set: False",
    "XEphem*Earth*grid.set: True",
    "XEphem*Earth*inertial.set: False",
    "XEphem*Earth*livedrag.set: True",
    "XEphem*Earth*lowprec.set: False",
    "XEphem*Earth*mainmarker.set: True",
    "XEphem*Earth*nightlights.set: True",
    "XEphem*Earth*object.set: True",
    "XEphem*Earth*sites.set: False",
    "XEphem*Earth*sphGraphic.set: False",
    "XEphem*Earth*sphImage.set: True",
    "XEphem*Earth*sunlight.set: True",
    "XEphem*Earth*track.set: False",
    "XEphem*Earth*trail.set: True",
    "XEphem*Earth*wxmap.set: False",
    "XEphem*Earth.height: 535",
    "XEphem*Earth.width: 545",
    "XEphem*Earth.x: 482",
    "XEphem*Earth.y: 87",
    "XEphem*EarthObjs.x: 5",
    "XEphem*EarthObjs.y: 350",
    "XEphem*Equatorial.Topocentric.set: True",
    "XEphem*ExtFile*Text.value:",
    "XEphem*Favorites.height: 420",
    "XEphem*Favorites.width: 250",
    "XEphem*Favorites.x: 200",
    "XEphem*Favorites.y: 200",
    "XEphem*Favorites*File.value:",
    "XEphem*Favorites*edb.value:",
    "XEphem*FieldStars*DupMag.value: 3",
    "XEphem*FieldStars*DupSep.value: 4",
    "XEphem*FieldStars*GSC22.set: False",
    "XEphem*FieldStars*GSC22Dir.value:",
    "XEphem*FieldStars*GSC23Net.set: False",
    "XEphem*FieldStars*GSC23URL.value:",
    "XEphem*FieldStars*GSCCD.set: False",
    "XEphem*FieldStars*GSCCDDirectory.value:",
    "XEphem*FieldStars*GSCCache.set: False",
    "XEphem*FieldStars*GSCCacheDirectory.value:",
    "XEphem*FieldStars*NoDups.set: True",
    "XEphem*FieldStars*PPM.set: False",
    "XEphem*FieldStars*PPMFilename.value:",
    "XEphem*FieldStars*SAOHD.set: True",
    "XEphem*FieldStars*Tycho.set: False",
    "XEphem*FieldStars*TychoFilename.value:",
    "XEphem*FieldStars*UCAC.set: False",
    "XEphem*FieldStars*UCACDirectory.value:",
    "XEphem*FieldStars*USNO.set: False",
    "XEphem*FieldStars*USNODirectory.value:",
    "XEphem*FieldStars.x: 200",
    "XEphem*FieldStars.y: 100",
    "XEphem*Fonts*Pattern.value: *adobe*",
    "XEphem*Fonts.height: 600",
    "XEphem*Fonts.width: 450",
    "XEphem*Fonts.x: 418",
    "XEphem*Fonts.y: 4",
    "XEphem*Gallery*Report.height: 150",
    "XEphem*Gallery.height: 650",
    "XEphem*Gallery.width: 750",
    "XEphem*Gallery.x: 100",
    "XEphem*Gallery.y: 100",
    "XEphem*HelpConfig.width: 500",
    "XEphem*HelpConfig.x: 210",
    "XEphem*HelpConfig.y: 360",
    "XEphem*HelpConfig*BrowserChoice0.set: False",
    "XEphem*HelpConfig*BrowserChoice1.set: True",
    "XEphem*HelpConfig*BrowserChoice2.set: False",
    "XEphem*HelpConfig*BrowserChoice3.set: False",
    "XEphem*HelpConfig*BrowserChoice4.set: False",
    "XEphem*HelpConfig*BrowserChoice5.set: False",
    "XEphem*HelpConfig*BrowserChoice6.set: False",
    "XEphem*HelpConfig*BrowserName0.value: mozilla",
    "XEphem*HelpConfig*BrowserName1.value: firefox",
    "XEphem*HelpConfig*BrowserName2.value: opera",
    "XEphem*HelpConfig*BrowserName3.value: konqueror",
    "XEphem*HelpConfig*BrowserName4.value: safari",
    "XEphem*HelpConfig*BrowserName5.value: MS IE",
    "XEphem*HelpConfig*BrowserName6.value: chrome",
    "XEphem*HelpConfig*BrowserCmd0.value: mozilla -remote 'openURL(%s)'",
    "XEphem*HelpConfig*BrowserCmd1.value: firefox '%s'",
    "XEphem*HelpConfig*BrowserCmd2.value: opera -remote 'openURL(%s)'",
    "XEphem*HelpConfig*BrowserCmd3.value: kfmclient openURL '%s'",
    "XEphem*HelpConfig*BrowserCmd4.value: osascript -e 'tell application \"safari\"' -e 'set the URL of the front document to \"%s\"' -e 'end tell'",
    "XEphem*HelpConfig*BrowserCmd5.value: C:/Program*/Internet*/IEXPLORE.EXE \"%s\"",
    "XEphem*HelpConfig*BrowserCmd6.value: google-chrome '%s'",
    "XEphem*Horizon*Displacement.value: 0",
    "XEphem*Horizon*MapFilename.value: sample.hzn",
    "XEphem*Horizon*SaveFilename.value: myhorizon.hzn",
    "XEphem*Horizon*UseDisplacement.set: False",
    "XEphem*Horizon.x: 100",
    "XEphem*Horizon.y: 50",
    "XEphem*ImReg.x: 200",
    "XEphem*ImReg.y: 200",
    "XEphem*INDI*Connect.set: False",
    "XEphem*INDI*traceFile.value: inditrace.txt",
    "XEphem*INDI*traceOn.set: False",
    "XEphem*INDI.height: 650",
    "XEphem*INDI.width: 550",
    "XEphem*INDI.x: 450",
    "XEphem*INDI.y: 50",
    "XEphem*INDIConfig*EDBValue.value: Mount.GOTOedb.edb",
    "XEphem*INDIConfig*EnableEDB.set: False",
    "XEphem*INDIConfig*EnableRADec.set: False",
    "XEphem*INDIConfig*TelEOD.set: False",
    "XEphem*INDIConfig*GotoDecOffset.value: 0",
    "XEphem*INDIConfig*GotoDecSlope.value: .01745329251994329576",
    "XEphem*INDIConfig*GotoDecValue.value: Telescope.SetRADec2K.Dec",
    "XEphem*INDIConfig*GotoRAOffset.value: 0",
    "XEphem*INDIConfig*GotoRASlope.value: .26179938779914943653",
    "XEphem*INDIConfig*GotoRAValue.value: Telescope.SetRADec2K.RA",
    "XEphem*INDIConfig*Host.value: localhost",
    "XEphem*INDIConfig*JDOffset.value: -2415020",
    "XEphem*INDIConfig*JDSlope.value: 1",
    "XEphem*INDIConfig*JDValue.value: Mount.Date.JD",
    "XEphem*INDIConfig*LatitudeOffset.value: 0",
    "XEphem*INDIConfig*LatitudeSlope.value: .01745329251994329576",
    "XEphem*INDIConfig*LatitudeValue.value: Mount.GEOGRAPHIC_COORD.LAT",
    "XEphem*INDIConfig*LongitudeOffset.value: 0",
    "XEphem*INDIConfig*LongitudeSlope.value: .01745329251994329576",
    "XEphem*INDIConfig*LongitudeValue.value: Mount.GEOGRAPHIC_COORD.LONG",
    "XEphem*INDIConfig*POSIXTMValue.value: Mount.Date.POSIX",
    "XEphem*INDIConfig*Port.value: 7624",
    "XEphem*INDIConfig*PressureOffset.value: 0",
    "XEphem*INDIConfig*PressureSlope.value: 1",
    "XEphem*INDIConfig*PressureValue.value: Weather.WX.Pres",
    "XEphem*INDIConfig*Recenter.set: False",
    "XEphem*INDIConfig*SkyDecOffset.value: 0",
    "XEphem*INDIConfig*SkyDecSlope.value: .01745329251994329576",
    "XEphem*INDIConfig*SkyDecValue.value: Telescope.Pointing.Dec2K",
    "XEphem*INDIConfig*SkyMarker.set: False",
    "XEphem*INDIConfig*SkyRAOffset.value: 0",
    "XEphem*INDIConfig*SkyRASlope.value: .26179938779914943653",
    "XEphem*INDIConfig*SkyRAValue.value: Telescope.Pointing.RA2K",
    "XEphem*INDIConfig*TemperatureOffset.value: 0",
    "XEphem*INDIConfig*TemperatureSlope.value: 1",
    "XEphem*INDIConfig*TemperatureValue.value: Weather.WX.Temp",
    "XEphem*INDIConfig.x: 100",
    "XEphem*INDIConfig.y: 100",
    "XEphem*Jupiter*BrightMoons.set: False",
    "XEphem*Jupiter*FlipLR.set: False",
    "XEphem*Jupiter*FlipTB.set: False",
    "XEphem*Jupiter*LimMag.value: 10",
    "XEphem*Jupiter*Scale.value: 36",
    "XEphem*Jupiter*SkyBkg.set: False",
    "XEphem*Jupiter*Tags.set: True",
    "XEphem*Jupiter.height: 350",
    "XEphem*Jupiter.width: 350",
    "XEphem*Jupiter.x: 356",
    "XEphem*Jupiter.y: 395",
    "XEphem*JupiterStats*GRSSysIILong.value: 190",
    "XEphem*JupiterStats.x: 200",
    "XEphem*JupiterStats.y: 50",
    "XEphem*JupiterTV*JupiterTop.height: 300",
    "XEphem*List*Filename.value:",
    "XEphem*List*ConfigFile.value: mylist.lsc",
    "XEphem*List*Headings.set: True",
    "XEphem*List*LaTex.set: False",
    "XEphem*List.x: 200",
    "XEphem*List.y: 200",
    "XEphem*LogBell.Off.set: True",
    "XEphem*Logbook.x: 400",
    "XEphem*Logbook.y: 30",
    "XEphem*LogList.x: 750",
    "XEphem*LogList.y: 30",
    "XEphem*LogList.width: 500",
    "XEphem*LogList.height: 500",
    "XEphem*LogList*filename.value: obslist.txt",
    "XEphem*MainForm.XmFrame.bottomOffset: 1",
    "XEphem*MainForm.XmFrame.leftOffset: 1",
    "XEphem*MainForm.XmFrame.marginHeight: 1",
    "XEphem*MainForm.XmFrame.marginWidth: 1",
    "XEphem*MainForm.XmFrame.rightOffset: 1",
    "XEphem*MainForm.XmFrame.topOffset: 1",
    "XEphem*Mars*FlipLR.set: False",
    "XEphem*Mars*FlipTB.set: False",
    "XEphem*Mars*Grid.set: True",
    "XEphem*Mars*HalfSize.set: True",
    "XEphem*Mars*Labels.set: False",
    "XEphem*Mars*LowPrec.set: False",
    "XEphem*Mars*SkyBkg.set: False",
    "XEphem*Mars.height: 650",
    "XEphem*Mars.width: 580",
    "XEphem*Mars.x: 350",
    "XEphem*Mars.y: 47",
    "XEphem*MarsFeatures*Albedo.set: False",
    "XEphem*MarsFeatures*Catena.set: False",
    "XEphem*MarsFeatures*Cavus.set: False",
    "XEphem*MarsFeatures*Chaos.set: False",
    "XEphem*MarsFeatures*Chasma.set: False",
    "XEphem*MarsFeatures*Colles.set: False",
    "XEphem*MarsFeatures*Crater.set: False",
    "XEphem*MarsFeatures*Dorsum.set: False",
    "XEphem*MarsFeatures*Fluctus.set: False",
    "XEphem*MarsFeatures*Fossa.set: False",
    "XEphem*MarsFeatures*Labes.set: False",
    "XEphem*MarsFeatures*Labyrinthus.set: False",
    "XEphem*MarsFeatures*Landing.set: True",
    "XEphem*MarsFeatures*Mensa.set: False",
    "XEphem*MarsFeatures*Mons.set: True",
    "XEphem*MarsFeatures*Patera.set: False",
    "XEphem*MarsFeatures*Planitia.set: False",
    "XEphem*MarsFeatures*Planum.set: False",
    "XEphem*MarsFeatures*Rupes.set: False",
    "XEphem*MarsFeatures*Scopulus.set: False",
    "XEphem*MarsFeatures*Sulcus.set: False",
    "XEphem*MarsFeatures*Terra.set: False",
    "XEphem*MarsFeatures*Tholus.set: False",
    "XEphem*MarsFeatures*Undae.set: False",
    "XEphem*MarsFeatures*Vallis.set: False",
    "XEphem*MarsFeatures*Vastitas.set: False",
    "XEphem*MarsFeatures.x: 200",
    "XEphem*MarsFeatures.y: 50",
    "XEphem*MarsMoonStats.x: 200",
    "XEphem*MarsMoonStats.y: 50",
    "XEphem*MarsMoons*BrightMoons.set: False",
    "XEphem*MarsMoons*FlipLR.set: False",
    "XEphem*MarsMoons*FlipTB.set: False",
    "XEphem*MarsMoons*LimMag.value: 17",
    "XEphem*MarsMoons*MarsMoons.foreground: #fa5",
    "XEphem*MarsMoons*Scale.value: 50",
    "XEphem*MarsMoons*SkyBkg.set: False",
    "XEphem*MarsMoons*Tags.set: True",
    "XEphem*MarsMoons.height: 350",
    "XEphem*MarsMoons.width: 350",
    "XEphem*MarsMoons.x: 200",
    "XEphem*MarsMoons.y: 200",
    "XEphem*MarsMoonsTV*MarsTop.height: 300",
    "XEphem*MarsStats*Seeing.value: 0",
    "XEphem*MarsStats.x: 200",
    "XEphem*MarsStats.y: 50",
    "XEphem*Moon*FlipLR.set: False",
    "XEphem*Moon*FlipTB.set: False",
    "XEphem*Moon*Grid.set: False",
    "XEphem*Moon*Image.set: True",
    "XEphem*Moon*Labels.set: True",
    "XEphem*Moon*MoonMap.foreground: #fff",
    "XEphem*Moon*Scale1X.set: False",
    "XEphem*Moon*Scale2X.set: False",
    "XEphem*Moon*Scale3X.set: True",
    "XEphem*Moon*Scale6X.set: False",
    "XEphem*Moon*SkyBkg.set: False",
    "XEphem*Moon*Spacecraft.set: True",
    "XEphem*Moon*Umbra.set: True",
    "XEphem*Moon.height: 470",
    "XEphem*Moon.width: 585",
    "XEphem*Moon.x: 570",
    "XEphem*Moon.y: 10",
    "XEphem*MoonEShine*Earthshine.value: 4",
    "XEphem*MoonEShine.x: 200",
    "XEphem*MoonEShine.y: 50",
    "XEphem*MoonLO*Overlay.set: True",
    "XEphem*MoonLO.height: 600",
    "XEphem*MoonLO.width: 500",
    "XEphem*MoonLO.x: 20",
    "XEphem*MoonLO.y: 10",
    "XEphem*MoonStats.x: 200",
    "XEphem*MoonStats.y: 50",
    "XEphem*Movie.x: 400",
    "XEphem*Movie.y: 100",
    "XEphem*Movie.width: 500",
    "XEphem*Movie.height: 500",
    "XEphem*NaaGlance*OneColor.set: True",
    "XEphem*NaaGlance.height: 400",
    "XEphem*NaaGlance.width: 450",
    "XEphem*NaaGlance.x: 200",
    "XEphem*NaaGlance.y: 200",
    "XEphem*NetSetup*Auth.set: False",
    "XEphem*NetSetup*AuthName.value: ",
    "XEphem*NetSetup*AuthPassword.value: ",
    "XEphem*NetSetup*Direct.set: True",
    "XEphem*NetSetup*Proxy.set: False",
    "XEphem*NetSetup*ProxyHost.value: a.b.com",
    "XEphem*NetSetup*ProxyPort.value: 8000",
    "XEphem*NetSetup*SOCKS.set: False",
    "XEphem*NetSetup*SOCKSHost.value: x.y.com",
    "XEphem*NetSetup*SOCKSPort.value: 1080",
    "XEphem*NetSetup.x: 7",
    "XEphem*NetSetup.y: 583",
    "XEphem*Objects*All.set: True",
    "XEphem*Objects*DeepSky.set: False",
    "XEphem*Objects*Binaries.set: False",
    "XEphem*Objects*EarthSat.set: False",
    "XEphem*Objects*SolSys.set: False",
    "XEphem*Objects*Stellar.set: False",
    "XEphem*Objects.x: 100",
    "XEphem*Objects.y: 200",
    "XEphem*Plot*ConfigFile.value: myplot.ptc",
    "XEphem*Plot*PlotFile.value:",
    "XEphem*Plot.x: 200",
    "XEphem*Plot.y: 200",
    "XEphem*PlotMap.background: #101010",
    "XEphem*PlotMap.foreground: #68a368",
    "XEphem*PlotMap.height: 350",
    "XEphem*PlotMap.width: 350",
    "XEphem*PlotDisplay*FlipX.set: False",
    "XEphem*PlotDisplay*FlipY.set: False",
    "XEphem*PlotDisplay*Grid.set: True",
    "XEphem*PlotDisplay*XYrAsDate.set: False",
    "XEphem*PlotDisplay*XJDAsDate.set: False",
    "XEphem*Precision.Hi.set: True",
    "XEphem*Print*A4.set: False",
    "XEphem*Print*Color.set: False",
    "XEphem*Print*Filename.value:",
    "XEphem*Print*PrintCmd.value: lpr",
    "XEphem*Print*Save.set: True",
    "XEphem*Print*Thick.set: False",
    "XEphem*Print.x: 100",
    "XEphem*Print.y: 100",
    "XEphem*Progress*DA.foreground: #68a368",
    "XEphem*Progress*DA.height: 20",
    "XEphem*Progress*DA.width: 150",
    "XEphem*Progress.x: 20",
    "XEphem*Progress.y: 500",
    "XEphem*PromptPreFill.No.set: False",
    "XEphem*Saturn*BrightMoons.set: False",
    "XEphem*Saturn*FlipLR.set: False",
    "XEphem*Saturn*FlipTB.set: False",
    "XEphem*Saturn*LimMag.value: 15",
    "XEphem*Saturn*Scale.value: 31",
    "XEphem*Saturn*SkyBkg.set: False",
    "XEphem*Saturn*Tags.set: True",
    "XEphem*Saturn.height: 350",
    "XEphem*Saturn.width: 350",
    "XEphem*Saturn.x: 431",
    "XEphem*Saturn.y: 376",
    "XEphem*SaturnStats.x: 200",
    "XEphem*SaturnStats.y: 50",
    "XEphem*SaturnTV*SaturnTop.height: 300",
    "XEphem*SaveRes*AutoMinorSel.set: False",
    "XEphem*SaveRes*AutoSave.set: False",
    "XEphem*SaveRes*AutoSel.set: True",
    "XEphem*SaveRes.height: 500",
    "XEphem*SaveRes.width: 533",
    "XEphem*SaveRes.x: 361",
    "XEphem*SaveRes.y: 3",
    "XEphem*Sites*SiteSL.visibleItemCount: 12",
    "XEphem*Sites.x: 50",
    "XEphem*Sites.y: 50",
    "XEphem*SkyEyep*ApparentFOV.value: 45",
    "XEphem*SkyEyep*Elliptical.set: True",
    "XEphem*SkyEyep*EyepH.value: 50",
    "XEphem*SkyEyep*EyepA.value: 0",
    "XEphem*SkyEyep*EyepW.value: 50",
    "XEphem*SkyEyep*EyepieceFL.value: 12mm",
    "XEphem*SkyEyep*FPlaneSize.value: 35mm",
    "XEphem*SkyEyep*EyePDefFile.value:",
    "XEphem*SkyEyep*FocalLength.value: 50mm",
    "XEphem*SkyEyep*Lock.set: False",
    "XEphem*SkyEyep*MirrorFL.value: 2000mm",
    "XEphem*SkyEyep*EyePPosFile.value:",
    "XEphem*SkyEyep*Solid.set: False",
    "XEphem*SkyEyep*Telrad.set: False",
    "XEphem*SkyEyep.x: 200",
    "XEphem*SkyEyep.y: 50",
    "XEphem*SkyFITS*AutoName.set: True",
    "XEphem*SkyFITS*DSS1.set: True",
    "XEphem*SkyFITS*DSS2B.set: False",
    "XEphem*SkyFITS*DSS2R.set: False",
    "XEphem*SkyFITS*Header.columns: 40",
    "XEphem*SkyFITS*Header.rows: 8",
    "XEphem*SkyFITS*SaveFile.value: myimage.fts",
    "XEphem*SkyFITS*STScI.set: True",
    "XEphem*SkyFITS*WatchFile.value: watch.txt",
    "XEphem*SkyFITS.width: 300",
    "XEphem*SkyFITS.height: 700",
    "XEphem*SkyFITS.x: 600",
    "XEphem*SkyFITS.y: 10",
    "XEphem*SkyFilter*Binary.set: True",
    "XEphem*SkyFilter*BrightNeb.set: True",
    "XEphem*SkyFilter*ClInNeb.set: True",
    "XEphem*SkyFilter*DarkNeb.set: True",
    "XEphem*SkyFilter*DeepSkyMag.value: 7",
    "XEphem*SkyFilter*DiffuseNeb.set: True",
    "XEphem*SkyFilter*Double.set: True",
    "XEphem*SkyFilter*EarthSat.set: True",
    "XEphem*SkyFilter*Elliptical.set: True",
    "XEphem*SkyFilter*GalClusters.set: True",
    "XEphem*SkyFilter*GlobularCl.set: True",
    "XEphem*SkyFilter*Hyperbolic.set: True",
    "XEphem*SkyFilter*MagStep.value: 1",
    "XEphem*SkyFilter*Multiple.set: True",
    "XEphem*SkyFilter*OpenCl.set: True",
    "XEphem*SkyFilter*Parabolic.set: True",
    "XEphem*SkyFilter*PlanetaryNeb.set: True",
    "XEphem*SkyFilter*Planets.set: True",
    "XEphem*SkyFilter*Pulsars.set: True",
    "XEphem*SkyFilter*Quasars.set: True",
    "XEphem*SkyFilter*Radio.set: True",
    "XEphem*SkyFilter*SNRemnants.set: True",
    "XEphem*SkyFilter*SolSysMag.value: 7",
    "XEphem*SkyFilter*SphericalGal.set: True",
    "XEphem*SkyFilter*SpiralGal.set: True",
    "XEphem*SkyFilter*StarMag.value: 7",
    "XEphem*SkyFilter*Stars.set: True",
    "XEphem*SkyFilter*Stellar.set: True",
    "XEphem*SkyFilter*Supernova.set: True",
    "XEphem*SkyFilter*SymbolDA.background: #101010",
    "XEphem*SkyFilter*SymbolDA.foreground: #c0c0c0",
    "XEphem*SkyFilter*SymbolDA.width: 25",
    "XEphem*SkyFilter*Undefined.set: True",
    "XEphem*SkyFilter*Variable.set: True",
    "XEphem*SkyFilter.x: 68",
    "XEphem*SkyFilter.y: 10",
    "XEphem*SkyHist.height: 250",
    "XEphem*SkyHist.width: 700",
    "XEphem*SkyHist.x: 20",
    "XEphem*SkyHist.y: 50",
    "XEphem*SkyIP*Contrast.Reverse.set: False",
    "XEphem*SkyIP*ContrastSection.set: True",
    "XEphem*SkyIP*GammaScale.value: 75",
    "XEphem*SkyIP*Gaussian*RefMag.value: 0",
    "XEphem*SkyIP*GaussianSection.set: False",
    "XEphem*SkyIP*Glass*ColPlot.background: #333",
    "XEphem*SkyIP*Glass*ColPlot.height: 120",
    "XEphem*SkyIP*Glass*Mag*1x.set: False",
    "XEphem*SkyIP*Glass*Mag*2x.set: True",
    "XEphem*SkyIP*Glass*Mag*4x.set: False",
    "XEphem*SkyIP*Glass*Mag*8x.set: False",
    "XEphem*SkyIP*Glass*Plot.Column.set: False",
    "XEphem*SkyIP*Glass*Plot.Row.set: False",
    "XEphem*SkyIP*Glass*RowPlot.background: #333",
    "XEphem*SkyIP*Glass*RowPlot.height: 120",
    "XEphem*SkyIP*Glass*Size*128x128.set: False",
    "XEphem*SkyIP*Glass*Size*16x16.set: False",
    "XEphem*SkyIP*Glass*Size*32x32.set: False",
    "XEphem*SkyIP*Glass*Size*64x64.set: True",
    "XEphem*SkyIP*GlassSection.set: False",
    "XEphem*SkyIP*Histogram.background: #333",
    "XEphem*SkyIP*Histogram.height: 50",
    "XEphem*SkyIP*ROISection.set: False",
    "XEphem*SkyIP*Slice.FullScale.set: True",
    "XEphem*SkyIP*SlicePlot.background: #333",
    "XEphem*SkyIP*SlicePlot.height: 120",
    "XEphem*SkyIP*SliceSection.set: False",
    "XEphem*SkyIP.x: 50",
    "XEphem*SkyIP.y: 10",
    "XEphem*SkyList*EdbFilename.value:",
    "XEphem*SkyList*List.rows: 10",
    "XEphem*SkyList*Text.set: True",
    "XEphem*SkyList*TextFilename.value:",
    "XEphem*SkyList.x: 200",
    "XEphem*SkyList.y: 50",
    "XEphem*SkyOps*AltAzMode.set: True",
    "XEphem*SkyOps*AutoMag.set: True",
    "XEphem*SkyOps*CnsAbbr.set: False",
    "XEphem*SkyOps*CnsBoundaries.set: False",
    "XEphem*SkyOps*CnsFigures.set: True",
    "XEphem*SkyOps*CnsNames.set: False",
    "XEphem*SkyOps*Compass.set: True",
    "XEphem*SkyOps*CylProj.set: False",
    "XEphem*SkyOps*Ecliptic.set: True",
    "XEphem*SkyOps*Equator.set: False",
    "XEphem*SkyOps*Eyepieces.set: True",
    "XEphem*SkyOps*FieldStars.set: True",
    "XEphem*SkyOps*FlipLR.set: False",
    "XEphem*SkyOps*FlipTB.set: False",
    "XEphem*SkyOps*Galactic.set: True",
    "XEphem*SkyOps*Grid*AltAz.set: False",
    "XEphem*SkyOps*Grid*Auto.set: True",
    "XEphem*SkyOps*Grid*Grid.set: False",
    "XEphem*SkyOps*Grid*Labels.set: True",
    "XEphem*SkyOps*Grid*HGrid.value: 1:00:00",
    "XEphem*SkyOps*Grid*VGrid.value: 15:00:00",
    "XEphem*SkyOps*HznMap.set: False",
    "XEphem*SkyOps*JustDots.set: True",
    "XEphem*SkyOps*LblDSMag.set: False",
    "XEphem*SkyOps*LblDSName.set: True",
    "XEphem*SkyOps*LblFSMag.set: True",
    "XEphem*SkyOps*LblFSName.set: False",
    "XEphem*SkyOps*LblNDeepSky.value: 19",
    "XEphem*SkyOps*LblNFStars.value: 10",
    "XEphem*SkyOps*LblNSolSys.value: 20",
    "XEphem*SkyOps*LblNStars.value: 48",
    "XEphem*SkyOps*LblSSMag.set: False",
    "XEphem*SkyOps*LblSSName.set: True",
    "XEphem*SkyOps*LblStMag.set: False",
    "XEphem*SkyOps*LblStName.set: True",
    "XEphem*SkyOps*LiveDrag.set: True",
    "XEphem*SkyOps*ClipObjects.set: False",
    "XEphem*SkyOps*MagScale.set: True",
    "XEphem*SkyOps*LiveReport.set: True",
    "XEphem*SkyOps.x: 64",
    "XEphem*SkyOps.y: 50",
    "XEphem*SkyView*AltDecScale.scaleMultiple: 1",
    "XEphem*SkyView*AltDecScale.value: 1080",
    "XEphem*SkyView*AzRAScale.scaleMultiple: 1",
    "XEphem*SkyView*AzRAScale.value: 2160",
    "XEphem*SkyView*FOVScale.scaleMultiple: 1",
    "XEphem*SkyView*FOVScale.value: 2160",
    "XEphem*SkyView*LToolbar*shadowThickness: 1",
    "XEphem*SkyView*LToolbar*spacing: 2",
    "XEphem*SkyView*RToolbar*shadowThickness: 1",
    "XEphem*SkyView*RToolbar*spacing: 2",
    "XEphem*SkyView*TToolbar*shadowThickness: 1",
    "XEphem*SkyView*TToolbar*spacing: 2",
    "XEphem*SkyView*translations: #override    \\n"
	"None<Key>KP_Left:      SVScut(0,-.02) \\n"
	"Shift<Key>KP_Left:     SVScut(0,-.10) \\n"
	"None<Key>KP_Right:     SVScut(0, .02) \\n"
	"Shift<Key>KP_Right:    SVScut(0, .10) \\n"
	"None<Key>KP_Up:        SVScut(1, .02) \\n"
	"Shift<Key>KP_Up:       SVScut(1, .10) \\n"
	"None<Key>KP_Down:      SVScut(1,-.02) \\n"
	"Shift<Key>KP_Down:     SVScut(1,-.10) \\n"
	"None<Key>KP_Add:       SVScut(2, .98) \\n"
	"Shift<Key>KP_Add:      SVScut(2, .90) \\n"
	"None<Key>KP_Subtract:  SVScut(2,1.02) \\n"
	"Shift<Key>KP_Subtract: SVScut(2,1.10) \\n"
	"Ctrl<Key>f: 		XeGo(1)        \\n"
	"Ctrl<Key>b: 		XeGo(-1)       \\n"
	"Ctrl<Key>u: 		XeGo(0)",
    "XEphem*SkyView.height: 600",
    "XEphem*SkyView.width: 600",
    "XEphem*SkyView.x: 258",
    "XEphem*SkyView.y: 10",
    "XEphem*SolarSystem*DBToo.set: False",
    "XEphem*SolarSystem*DistScale.value: 50",
    "XEphem*SolarSystem*Ecliptic.set: True",
    "XEphem*SolarSystem*HLatScale.value: 90",
    "XEphem*SolarSystem*HLongScale.value: 0",
    "XEphem*SolarSystem*Labels.set: True",
    "XEphem*SolarSystem*Legs.set: True",
    "XEphem*SolarSystem*LiveDrag.set: True",
    "XEphem*SolarSystem*SolSysMap.foreground: #68a368",
    "XEphem*SolarSystem*Trails.set: True",
    "XEphem*SolarSystem*translations: #override \\n"
	"None<Key>KP_Left:      SSScut(0, -2)   \\n"
	"Shift<Key>KP_Left:     SSScut(0,-10)   \\n"
	"None<Key>KP_Right:     SSScut(0,  2)   \\n"
	"Shift<Key>KP_Right:    SSScut(0, 10)   \\n"
	"None<Key>KP_Up:        SSScut(1,  2)   \\n"
	"Shift<Key>KP_Up:       SSScut(1, 10)   \\n"
	"None<Key>KP_Down:      SSScut(1, -2)   \\n"
	"Shift<Key>KP_Down:     SSScut(1,-10)   \\n"
	"None<Key>KP_Add:       SSScut(2,  2)   \\n"
	"Shift<Key>KP_Add:      SSScut(2, 10)   \\n"
	"None<Key>KP_Subtract:  SSScut(2, -2)   \\n"
	"Shift<Key>KP_Subtract: SSScut(2,-10)   \\n"
	"None<Key>KP_Multiply:  SSScut(3,  1)   \\n"
	"None<Key>KP_Divide:    SSScut(3, -1)   \\n"
	"Ctrl<Key>f: 		XeGo(1)         \\n"
	"Ctrl<Key>b: 		XeGo(-1)        \\n"
	"Ctrl<Key>u: 		XeGo(0)",
    "XEphem*SolarSystem.height: 400",
    "XEphem*SolarSystem.width: 400",
    "XEphem*SolarSystem.x: 495",
    "XEphem*SolarSystem.y: 217",
    "XEphem*Solve*FindMax.set: True",
    "XEphem*Solve*FindMin.set: False",
    "XEphem*Solve*Find0.set: False",
    "XEphem*Solve*Binary.set: False",
    "XEphem*Solve*Accuracy.value: 0:02:0",
    "XEphem*Solve*Function.rows: 5",
    "XEphem*Solve*Function.value:",
    "XEphem*Solve.x: 100",
    "XEphem*Solve.y: 100",
    "XEphem*Solve*ConfigFile.value: mysearch.svc",
    "XEphem*Splash*title.fontList: *-lucidatypewriter*medium*-12-*-iso8859-1",
    "XEphem*StereoSolarSystem*SSStereo.foreground: #68a368",
    "XEphem*SysLog*Log.columns: 90",
    "XEphem*SysLog*Log.rows: 20",
    "XEphem*SysLog.x: 40",
    "XEphem*SysLog.y: 40",
    "XEphem*Sun*1024x1024.set: False",
    "XEphem*Sun*256x256.set: False",
    "XEphem*Sun*512x512.set: True",
    "XEphem*Sun*BySize.set: False",
    "XEphem*Sun*ByType.set: False",
    "XEphem*Sun*EIT171.set: False",
    "XEphem*Sun*EIT195.set: False",
    "XEphem*Sun*EIT284.set: True",
    "XEphem*Sun*EIT304.set: False",
    "XEphem*Sun*LASC2.set: False",
    "XEphem*Sun*LASC3.set: False",
    "XEphem*Sun*HMICon.set: False",
    "XEphem*Sun*HMIMag.set: False",
    "XEphem*Sun.height: 590",
    "XEphem*Sun.width: 530",
    "XEphem*Sun.x: 20",
    "XEphem*Sun.y: 20",
    "XEphem*TZone.Local.set: True",
    "XEphem*Telescope*Goto.set: True",
    "XEphem*Telescope*Marker.set: True",
    "XEphem*Telescope*NoHW.set: False",
    "XEphem*Telescope*Process.value: lx200xed",
    "XEphem*Telescope*Serial.value: /dev/ttyS0",
    "XEphem*Telescope.x: 200",
    "XEphem*Telescope.y: 50",
    "XEphem*Tips.No.set: False",
    "XEphem*TopLevelShell*translations: #override \\n"
	"Ctrl<Key>f: XeGo(1) \\n"
	"Ctrl<Key>b: XeGo(-1) \\n"
	"Ctrl<Key>u: XeGo(0)",
    "XEphem*Trails*CustomInterval.value: 0:30",
    "XEphem*Trails*NTicks.maximum: 250",
    "XEphem*Units.English.set: False",
    "XEphem*Uranus*BrightMoons.set: False",
    "XEphem*Uranus*FlipLR.set: False",
    "XEphem*Uranus*FlipTB.set: False",
    "XEphem*Uranus*LimMag.value: 17",
    "XEphem*Uranus*Scale.value: 34",
    "XEphem*Uranus*SkyBkg.set: False",
    "XEphem*Uranus*Tags.set: True",
    "XEphem*Uranus.height: 350",
    "XEphem*Uranus.width: 350",
    "XEphem*Uranus.x: 437",
    "XEphem*Uranus.y: 396",
    "XEphem*UranusStats.x: 200",
    "XEphem*UranusStats.y: 50",
    "XEphem*UranusTV*UranusTop.height: 300",
    "XEphem*WCS*BestAcc.value: 0.5",
    "XEphem*WCS*BurnedOut.value: 60000",
    "XEphem*WCS*Dec.value: 0 0 0",
    "XEphem*WCS*DecField.value: OBJCTDEC",
    "XEphem*WCS*RA.value: 0 0 0",
    "XEphem*WCS*RAField.value: OBJCTRA",
    "XEphem*WCS*Rotation.value: 0.0",
    "XEphem*WCS*RotationField.value: CROTA2",
    "XEphem*WCS*SNR.value: 10.0",
    "XEphem*WCS*StepUp.value: -1.0",
    "XEphem*WCS*StepUpField.value: CDELT2",
    "XEphem*WCS*StepRight.value: 1.0",
    "XEphem*WCS*StepRightField.value: CDELT1",
    "XEphem*WCS*WorstAcc.value: 1.0",
    "XEphem*WCS.x: 30",
    "XEphem*WCS.y: 10",
    "XEphem*WebDB*Pattern.value: ",
    "XEphem*WebDB*Search.set: False",
    "XEphem*WebDB*URL0.value: http://celestrak.org/NORAD/elements/stations.txt",
    "XEphem*WebDB*URL1.value: http://celestrak.org/NORAD/elements/science.txt",
    "XEphem*WebDB*URL2.value: http://celestrak.org/NORAD/elements/tle-new.txt",
    "XEphem*WebDB*URL3.value: http://celestrak.org/NORAD/elements/amateur.txt",
    "XEphem*WebDB*URL4.value: http://celestrak.org/NORAD/elements/visual.txt",
    "XEphem*WebDB*URL5.value: https://www.minorplanetcenter.net/iau/Ephemerides/Comets/Soft03Cmt.txt",
    "XEphem*WebDB*URL6.value: https://www.minorplanetcenter.net/iau/Ephemerides/CritList/Soft03CritList.txt",
    "XEphem*WebDB*URL7.value: https://www.minorplanetcenter.net/iau/Ephemerides/Distant/Soft03Distant.txt",
    "XEphem*WebDB*URL8.value: https://www.minorplanetcenter.net/iau/Ephemerides/Unusual/Soft03Unusual.txt",
    "XEphem*WebDB*URL9.value:",
    "XEphem*WebDB.x: 200",
    "XEphem*WebDB.y: 200",
    "XEphem*WeekStart.Monday.set: False",
    "XEphem*WeekStart.Saturday.set: False",
    "XEphem*WeekStart.Sunday.set: True",
    "XEphem*XmArrowButton.foreground: #fffafa",
    "XEphem*XmArrowButton.shadowThickness: 1",
    "XEphem*XmArrowButtonGadget.foreground: #fffafa",
    "XEphem*XmArrowButtonGadget.shadowThickness: 1",
    "XEphem*XmCascadeButton.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmCascadeButton.foreground: #fffafa",
    "XEphem*XmCascadeButton.shadowThickness: 1",
    "XEphem*XmCascadeButtonGadget.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmCascadeButtonGadget.foreground: #fffafa",
    "XEphem*XmCascadeButtonGadget.shadowThickness: 1",
    "XEphem*XmFrame.marginHeight: 0",
    "XEphem*XmFrame.marginWidth: 0",
    "XEphem*XmLabel.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmLabel.foreground: #fffafa",
    "XEphem*XmLabelGadget.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmLabelGadget.foreground: #fffafa",
    "XEphem*XmList.background: #547768",
    "XEphem*XmList.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmList.foreground: #fffafa",
    "XEphem*XmList.shadowThickness: 1",
    "XEphem*XmPushButton.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmPushButton.foreground: #fffafa",
    "XEphem*XmPushButton.shadowThickness: 1",
    "XEphem*XmPushButtonGadget.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmPushButtonGadget.foreground: #fffafa",
    "XEphem*XmPushButtonGadget.shadowThickness: 1",
    "XEphem*XmRowColumn.shadowThickness: 1",
    "XEphem*XmScale.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmScale.foreground: #fffafa",
    "XEphem*XmScale.shadowThickness: 1",
    "XEphem*XmScrollBar.shadowThickness: 1",
    "XEphem*XmText.background: #547768",
    "XEphem*XmText.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmText.foreground: #fffafa",
    "XEphem*XmText.shadowThickness: 1",
    "XEphem*XmTextField.background: #547768",
    "XEphem*XmTextField.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmTextField.foreground: #fffafa",
    "XEphem*XmTextField.shadowThickness: 1",
    "XEphem*XmToggleButton.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmToggleButton.foreground: #fffafa",
    "XEphem*XmToggleButtonGadget.fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*XmToggleButtonGadget.foreground: #fffafa",
    "XEphem*background: #3B4F47",
    "XEphem*blinkRate: 0",
    "XEphem*fontList: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem*foreground: black",
    "XEphem*highlightThickness: 0",
    "XEphem*marginHeight: 1",
    "XEphem*marginLeft: 1",
    "XEphem*marginRight: 1",
    "XEphem*marginWidth: 1",
    "XEphem*spacing: 1",
    "XEphem.AnnoColor: #ffd200",
    "XEphem.AnnoFont: *-helvetica-medium-r-*-10-*-iso8859-1",
    "XEphem.AutoMag: .2 22 22 22 1, .3 21 21 21 1, .4 19 19 19 1, .5 17 17 17 1, .70 15 15 15 1, 1.11 14 14 14 1, 1.75 13 13 13 1, 2.78 12 12 12 1, 4.40 11 11 11 1, 6.97 10 10 10 1, 11.03  9 10 10 1, 17.39  8 9 9 1, 27.25  7 7 7 1, 42.04  6  6  6 1, 180.00  6  6  6 1",
    "XEphem.AutoRT: 0",
    "XEphem.CalOtherMonthColor: gray50",
    "XEphem.CnsFigFile: classicfigs.csf",
    "XEphem.CnsFont: *-times-medium-i-*-14-*-iso8859-1",
    "XEphem.DBinitialFiles: Messier.edb SKY2k65.edb",
    "XEphem.DataViewUp: 0",
    "XEphem.DeltaT: (Auto)  64.12",
    "XEphem.DimStarColor: #666",
    "XEphem.EarthBackground: #151515",
    "XEphem.EarthBorderColor: #21a500",
    "XEphem.EarthEclipseColor: #333",
    "XEphem.EarthGridColor: #6b6635",
    "XEphem.EarthHereColor: #ffff60",
    "XEphem.EarthSiteColor: #ff9b00",
    "XEphem.EarthSunColor: #d3ce8c",
    "XEphem.EarthGreatCircleColor: #cc0000",
    "XEphem.EarthTrailState: 1 1 1 3 2 0 20 0 0.0",
    "XEphem.EarthViewUp: 0",
    "XEphem.Elevation: 0",
    "XEphem.Equinox: 2000.0",
    "XEphem.FITSpattern:  *.f*t*",
    "XEphem.GlassBorderColor: yellow",
    "XEphem.GraphBGColor: #333",
    "XEphem.HorizonColor: #d8d8d8",
    "XEphem.INDIAlertColor: #c90000",
    "XEphem.INDIBusyColor: #ffff00",
    "XEphem.INDIHostname: localhost",
    "XEphem.INDIIdleColor: #707070",
    "XEphem.INDIOkColor: #00c900",
    "XEphem.INDIPort: 7624",
    "XEphem.ImGridColor: #bbb",
    "XEphem.ImPlotColor1: orange",
    "XEphem.ImPlotColor2: yellow",
    "XEphem.ImPlotColor3: red",
    "XEphem.JD:",
    "XEphem.JupViewUp: 0",
    "XEphem.JupiterBackground: #151515",
    "XEphem.Lat: 0:0:0",
    "XEphem.Long: 0:0:0",
    "XEphem.MarsAnnotColor: #8f8",
    "XEphem.MarsBackground: #151515",
    "XEphem.MarsViewUp: 0",
    "XEphem.MoonAnnotColor: #ee0000",
    "XEphem.MoonBackground: #151515",
    "XEphem.MoonViewUp: 0",
    "XEphem.NSteps: 1",
    "XEphem.NaaGOneColor: #1895ff",
    "XEphem.NaaGViewUp: 0",
    "XEphem.NightColor: #7aa87a",
    "XEphem.Pause: 0",
    "XEphem.Pressure: 1010 hPa",
    "XEphem.SOHOhost: sohowww.nascom.nasa.gov",
    "XEphem.SatViewUp: 0",
    "XEphem.SaturnBackground: #151515",
    "XEphem.ShareDir: .",
    "XEphem.Sitename: Chicago, Illinois",
    "XEphem.SkyAnnotColor: #bfc1c6",
    "XEphem.SkyCnsBndColor: #435964",
    "XEphem.SkyCnsFigColor: #7fc149",
    "XEphem.SkyCnsNamColor: #a5ad7a",
    "XEphem.SkyColor: #151515",
    "XEphem.SkyEqColor: #ff0000",
    "XEphem.SkyEyePColor: #aa1010",
    "XEphem.SkyGridColor: #0068b9",
    "XEphem.SkyGridFont: *-helvetica*bold*-r-*10-*-iso8859-1",
    "XEphem.SkyMWColor: #c65400",
    "XEphem.SkyViewTrailState: 4 3 2 1 0 0 10 0 0.0",
    "XEphem.SkyViewUp: 0",
    "XEphem.SolSysBackground: #151515",
    "XEphem.SolSysTrailState: 8 4 2 1 3 0 100 0 0.0",
    "XEphem.SolSysViewUp: 0",
    "XEphem.StepSize: RT Clock",
    "XEphem.SunViewUp: 0",
    "XEphem.TZName: XXX",
    "XEphem.TZone: 0",
    "XEphem.Temp: 10.0 C",
    "XEphem.TwilightDip: 18",
    "XEphem.UranusBackground: #151515",
    "XEphem.UranusViewUp: 0",
    "XEphem.cursorTrackingFont: *-lucidatypewriter*medium*-10-*-iso8859-1",
    "XEphem.install: guess",
    "XEphem.jupiterColor: #efe3d7",
    "XEphem.marsColor: #ffb568",
    "XEphem.mercuryColor: #d7b279",
    "XEphem.moonColor: #d9d9d9",
    "XEphem.moonsFont: *-helvetica-medium-r-*-10-*-iso8859-1",
    "XEphem.neptuneColor: #8eaaf7",
    "XEphem.otherObjColor: #7f7",
    "XEphem.plutoColor: #f7ebd7",
    "XEphem.satellitesColor: #faf",
    "XEphem.saturnColor: #efcb9e",
    "XEphem.solSysColor: #cfc",
    "XEphem.starSpectA: #cad7ff",
    "XEphem.starSpectB: #aabfff",
    "XEphem.starSpectC: #ff9040",
    "XEphem.starSpectF: #f8f7ff",
    "XEphem.starSpectG: #fff4ea",
    "XEphem.starSpectK: #ffd2a1",
    "XEphem.starSpectL: #ffb020",
    "XEphem.starSpectM: #ffcc6f",
    "XEphem.starSpectN: #ff8020",
    "XEphem.starSpectO: #9bb0ff",
    "XEphem.starSpectS: #ffa070",
    "XEphem.starSpectT: #ffa060",
    "XEphem.starSpectW: #c4c4ff",
    "XEphem.sunColor: #fffacd",
    "XEphem.tipBackground: #ffffbb",
    "XEphem.tipFont: *-helvetica-medium-r-*-10-*-iso8859-1",
    "XEphem.tipForeground: #000000",
    "XEphem.trailsFont: *-helvetica-medium-r-*-10-*-iso8859-1",
    "XEphem.uranusColor: #b6cbd7",
    "XEphem.venusColor: #ffebc7",
    "XEphem.viewsFont: *-times-medium-r-*-10-*-iso8859-1",
    "XEphem.viewsGreekFont: *-symbol-*-10-*",
    "XEphem.x: 50",
    "XEphem.y: 50",
    "XEphem*Logbook*Airmass.set: False",
    "XEphem*Logbook*Altitude.set: False",
    "XEphem*Logbook*Azimuth.set: False",
    "XEphem*Logbook*Camera.set: False",
    "XEphem*Logbook*Constel.set: False",
    "XEphem*Logbook*Date.set: False",
    "XEphem*Logbook*Dec2000.set: False",
    "XEphem*Logbook*Elongation.set: False",
    "XEphem*Logbook*Eyepiece.set: False",
    "XEphem*Logbook*Filter.set: False",
    "XEphem*Logbook*HJD.set: False",
    "XEphem*Logbook*JD.set: False",
    "XEphem*Logbook*Latitude.set: False",
    "XEphem*Logbook*Location.set: False",
    "XEphem*Logbook*Longitude.set: False",
    "XEphem*Logbook*MoonAlt.set: False",
    "XEphem*Logbook*MoonPhase.set: False",
    "XEphem*Logbook*MoonSep.set: False",
    "XEphem*Logbook*Object.set: False",
    "XEphem*Logbook*RA2000.set: False",
    "XEphem*Logbook*Seeing.set: False",
    "XEphem*Logbook*SunAlt.set: False",
    "XEphem*Logbook*Telescope.set: False",
    "XEphem*Logbook*Time.set: False",
    "XEphem*Logbook*Transparency.set: False",
    "XEphem*Logbook*UTCDate.set: False",
    "XEphem*Logbook*UTCTime.set: False",
    "XEphem*Logbook*User1.set: False",
    "XEphem*Logbook*User2.set: False",
    Version_resource,
    NULL
};

/* $Id: fallbacks.c,v 1.314 2021/12/14 19:10:39 ecdowney Exp $ */
